# -*- coding: utf-8 -*-

import json
import urllib
import datetime

from flask import Blueprint, url_for, flash, redirect, \
    render_template, request, current_app

from .wx import wx_login


bp = Blueprint("wxmp", __name__, template_folder="templates")


@bp.route("/login")
def wxmp_login():
    wx_login.init_app(current_app)
    oauth_type = request.args.get("oauth_type", "snsapi_userinfo")
    if oauth_type not in ("snsapi_userinfo", "snsapi_base", "snsapi_login"):
        oauth_type = "snsapi_userinfo"
    next = request.args.get("next") or request.referrer or "/"
    callback = url_for("wxmp.wxmp_authorized",
        oauth_type=oauth_type, next=next, _external=True)
    url = wx_login.authorize(urllib.parse.quote(callback), oauth_type)
    return redirect(url)


@bp.route("/authorized")
def wxmp_authorized():
    wx_login.init_app(current_app)
    code = request.args.get("code")
    if not code:
        return "ERR_INVALID_CODE", 400
    next = request.args.get("next", "/")
    oauth_type = request.args.get("oauth_type", "snsapi_userinfo")
    data = wx_login.access_token(code)
    # openid = data.openid
    # unionid = data.unionid
    resp = redirect(next)
    expires = datetime.datetime.now() + datetime.timedelta(hours=2)
    if oauth_type == "snsapi_userinfo":
        cookies_type = "WXMP_USER_COOKIES_NAME"
    else:
        cookies_type = "WXMP_BASE_COOKIES_NAME"
    cookies_name = current_app.config.get(cookies_type)
    resp.set_cookie(cookies_name, json.dumps(data), expires=expires)
    return resp
